/*
 *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
 *  m_servstart.c: Allows opers to view the TS the server was started on.
 *
 *  Copyright (C) 2002 by the past and present ircd coders, and others.
 *
 *  m_servstart.c - (C) Alan 'alz' Milford, 10th May 2003. (alz@froginternet.com)
 *
 *  Usage Details:
 * 
 *  This command is available for use by server operators (+o flag),
 * 
 *  /servstart - returns TS server was started on.
 * 
 *  Note: This command is completely pointless, it is basically a cut down
 *        version of /stats u.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 */

#include "stdinc.h"
#include "tools.h"
#include "handlers.h"
#include "channel.h"
#include "channel_mode.h"
#include "client.h"
#include "ircd.h"
#include "numeric.h"
#include "s_log.h"
#include "s_serv.h"
#include "send.h"
#include "whowas.h"
#include "irc_string.h"
#include "hash.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"
#include "list.h"

static void mo_servstart(struct Client *, struct Client *, int, char**);

struct Message servstart_msgtab = {
  "SERVSTART", 0, 0, 0, 0, MFLG_SLOW, 0,
  {m_unregistered, m_not_oper, m_ignore, mo_servstart}
};

#ifndef STATIC_MODULES

void
_modinit(void)
{
  mod_add_cmd(&servstart_msgtab);
}

void
_moddeinit(void)
{
  mod_del_cmd(&servstart_msgtab);
}

const char *_version = "1.0";
#endif

/*
** mo_servstart
**      parv[0] = sender prefix
*/
static void mo_servstart(struct Client *client_p, struct Client *source_p,
                        int parc, char *parv[])
{
  if (!IsOper(source_p))
    {
      sendto_one(source_p, ":%s NOTICE %s :You are not teh opered.", me.name, parv[0]);
      return;
    }
      sendto_one(source_p, ":%s NOTICE %s :Server Started: %lu", me.name, parv[0], me.since);
}